@@ -88,10 +88,8 @@ def get_data(cfg):
 
 
 def get_issue_refresh_tokens_value(cfg, facility_attrs):
-    for attr in facility_attrs:
-        attr_perun_name = attr["namespace"] + ":" + attr["baseFriendlyName"]
-        if attr_perun_name == cfg["attributes"]["issue_refresh_tokens"]:
-            return attr["value"] is True
+    value = facility_attrs.get(cfg["attributes"]["issue_refresh_tokens"])
+    return value is True
 
 
 def get_attr_dict(
